@@ -67,7 +67,6 @@ struct ci_server_conf {
     int MAX_SPARE_THREADS;
 
 #ifdef USE_OPENSSL
-    char *TLS_PASSPHRASE;
     int TLS_ENABLED;
 #endif
 };
@@ -80,7 +79,7 @@ struct ci_server_conf {
  * file.
  \code
  int AParam;
- struct ci_conf_entry conf_table[]= {
+ struct ci_conf_entry conf_table[] = {
     {"Aparameter", &AParam, ci_cfg_set_int, "This is a simple configuration parameter"},
     {NULL,NULL,NULL,NULL}
  }
@@ -160,6 +159,7 @@ int intl_cfg_size_long(const char *directive,const char **argv,void *setdata);
 
 CI_DECLARE_FUNC(void)   ci_cfg_lib_init();
 CI_DECLARE_FUNC(void)   ci_cfg_lib_reset();
+CI_DECLARE_FUNC(void)   ci_cfg_lib_destroy();
 CI_DECLARE_FUNC(void *) ci_cfg_alloc_mem(int size);
 
 /**
