@@ -50,7 +50,7 @@ extern "C"
  * body data to the ICAP client.
  \param req is pointer to an object of type ci_request_t
  */
-#define ci_req_lock_data(req) ((req)->data_locked=1)
+#define ci_req_lock_data(req) ((req)->data_locked = 1)
 
 /**
  \def ci_req_unlock_data(ci_request_t)
@@ -59,7 +59,7 @@ extern "C"
  * sending body data to the ICAP client.
  \param req is pointer to an object of type ci_request_t
  */
-#define ci_req_unlock_data(req) ((req)->data_locked=0)
+#define ci_req_unlock_data(req) ((req)->data_locked = 0)
 
 /**
  \def ci_req_hasbody(ci_request_t)
@@ -152,13 +152,24 @@ CI_DECLARE_FUNC(int) ci_base64_decode(const char *str,char *result,int len);
 CI_DECLARE_FUNC(int) ci_base64_encode(const unsigned char *data, size_t datalen, char *out, size_t outlen);
 
 enum {
-    CI_ENCODE_NONE=0,
+    CI_ENCODE_UNKNOWN = -1,
+    CI_ENCODE_NONE = 0,
     CI_ENCODE_GZIP,
     CI_ENCODE_DEFLATE,
     CI_ENCODE_BZIP2,
-    CI_ENCODE_UNKNOWN
+    CI_ENCODE_BROTLI,
+    CI_ENCODE_ZSTD
 };
 
+/**
+ * Return the encoding method integer representation from string.
+ \ingroup UTILITY
+ *
+ \param content_encoding The content encoding name
+ \return the CI_ENCODE_* representation
+*/
+CI_DECLARE_FUNC(int) ci_encoding_method(const char *content_encoding);
+
 /**
  * Uncompress a zipped string.
  \ingroup UTILITY
@@ -182,17 +193,54 @@ enum CI_UNCOMPRESS_ERRORS {
     CI_UNCOMP_OK = 1,
 };
 
+enum CI_COMPRESS_ERRORS {
+    CI_COMP_ERR_BOMB = -4,
+    CI_COMP_ERR_CORRUPT = -3,
+    CI_COMP_ERR_OUTPUT = -2,
+    CI_COMP_ERR_ERROR = -1,
+    CI_COMP_ERR_NONE = 0,
+    CI_COMP_OK = 1,
+};
+
 /**
- * Return a string representation of an uncompress error code.
+ * Return a string representation of a decompress error code.
  \ingroup UTILITY
  *
  \param err a CI_UNCOMPRESS_ERRORS error code
 */
+CI_DECLARE_FUNC(const char *) ci_decompress_error(int err);
+
+/**
+   Deprecated
+ */
 CI_DECLARE_FUNC(const char *) ci_inflate_error(int err);
 
 struct ci_membuf;
 struct ci_simple_file;
 
+/*  Data Decompression core functions */
+
+/**
+ * Uncompress any compressed data that c-icap understands and writes the output to the outbuf
+ * object, regardless of algorithm
+ \ingroup UTILITY
+ *
+ \param encoding_format   is the enum for the encoding type
+ \param inbuf   is a buffer which holds the zipped data
+ \param inlen is the length of the buffer buf
+ \param outbuf where to put unzipped data
+ \param max_size if it is greater than zero, the output data limit
+ \return CI_UNCOMP_OK on success, CI_UNCOMP_ERR_NONE, if maxsize exceed, an
+ *       CI_UNCOMPRESS_ERRORS code otherwise
+ */
+CI_DECLARE_FUNC(int) ci_decompress_to_membuf(int encoding_format, const char *inbuf, size_t inlen, struct ci_membuf *outbuf, ci_off_t max_size);
+
+/**
+ \ingroup UTILITY
+ \copydoc ci_decompress_to_membuf(char *inbuf, size_t inlen, struct ci_membuf *outbuf, ci_off_t max_size)
+ */
+CI_DECLARE_FUNC(int) ci_decompress_to_simple_file(int encoding_format, const char *inbuf, size_t inlen, struct ci_simple_file *outbuf, ci_off_t max_size);
+
 /**
  * Uncompress deflate/gzip compressed data and writes the output to the outbuf
  * object
@@ -232,6 +280,126 @@ CI_DECLARE_FUNC(int) ci_bzunzip_to_membuf(const char *inbuf, size_t inlen, struc
  */
 CI_DECLARE_FUNC(int) ci_bzunzip_to_simple_file(const char *inbuf, size_t inlen, struct ci_simple_file *outbuf, ci_off_t max_size);
 
+/**
+ * Uncompress brotli compressed data and writes the output to the outbuf object
+ \ingroup UTILITY
+ *
+ \param inbuf   is a buffer which holds the zipped data
+ \param inlen is the length of the buffer buf
+ \param outbuf where to put unzipped data
+ \param max_size if it is greater than zero, the output data limit
+ \return CI_UNCOMP_OK on success, CI_UNCOMP_ERR_NONE, if maxsize exceed, an
+ *       CI_UNCOMPRESS_ERRORS code otherwise
+ */
+CI_DECLARE_FUNC(int) ci_brinflate_to_membuf(const char *inbuf, size_t inlen, struct ci_membuf *outbuf, ci_off_t max_size);
+
+/**
+ \ingroup UTILITY
+ \copydoc ci_brinflate_to_membuf(char *inbuf, size_t inlen, struct ci_membuf *outbuf, ci_off_t max_size)
+ */
+CI_DECLARE_FUNC(int) ci_brinflate_to_simple_file(const char *inbuf, size_t inlen, struct ci_simple_file *outbuf, ci_off_t max_size);
+
+/*  Data Compression core functions */
+
+/**
+ * Compress any uncompressed data that c-icap understands and writes the output to the outbuf
+ * object, regardless of algorithm
+ \ingroup UTILITY
+ *
+ \param encoding_format   is the enum for the encoding type
+ \param inbuf   is a buffer which holds the unzipped data
+ \param inlen is the length of the buffer buf
+ \param outbuf where to put zipped data
+ \param max_size if it is greater than zero, the output data limit
+ \return CI_COMP_OK on success, CI_COMP_ERR_NONE, if maxsize exceed, an
+ *       CI_COMPRESS_ERRORS code otherwise
+ */
+CI_DECLARE_FUNC(int) ci_compress_to_membuf(int encoding_format, const char *inbuf, size_t inlen, struct ci_membuf *outbuf, ci_off_t max_size);
+
+/**
+ \ingroup UTILITY
+ \copydoc ci_compress_to_membuf(char *inbuf, size_t inlen, struct ci_membuf *outbuf, ci_off_t max_size)
+ */
+CI_DECLARE_FUNC(int) ci_compress_to_simple_file(int encoding_format, const char *inbuf, size_t inlen, struct ci_simple_file *outbuf, ci_off_t max_size);
+
+/**
+ * Compress deflate uncompressed data and writes the output to the outbuf
+ * object
+ \ingroup UTILITY
+ *
+ \param inbuf   is a buffer which holds the unzipped data
+ \param inlen is the length of the buffer buf
+ \param outbuf where to put zipped data
+ \param max_size if it is greater than zero, the output data limit
+ \return CI_COMP_OK on success, CI_COMP_ERR_NONE, if maxsize exceed, an
+ *       CI_COMPRESS_ERRORS code otherwise
+ */
+CI_DECLARE_FUNC(int) ci_deflate_to_membuf(const char *inbuf, size_t inlen, struct ci_membuf *outbuf, ci_off_t max_size);
+
+/**
+ \ingroup UTILITY
+ \copydoc ci_deflate_to_membuf(char *inbuf, size_t inlen, struct ci_membuf *outbuf, ci_off_t max_size)
+ */
+CI_DECLARE_FUNC(int) ci_deflate_to_simple_file(const char *inbuf, size_t inlen, struct ci_simple_file *outbuf, ci_off_t max_size);
+
+/**
+ * Compress gzip uncompressed data and writes the output to the outbuf
+ * object
+ \ingroup UTILITY
+ *
+ \param inbuf   is a buffer which holds the unzipped data
+ \param inlen is the length of the buffer buf
+ \param outbuf where to put zipped data
+ \param max_size if it is greater than zero, the output data limit
+ \return CI_COMP_OK on success, CI_COMP_ERR_NONE, if maxsize exceed, an
+ *       CI_COMPRESS_ERRORS code otherwise
+ */
+CI_DECLARE_FUNC(int) ci_gzip_to_membuf(const char *inbuf, size_t inlen, struct ci_membuf *outbuf, ci_off_t max_size);
+
+/**
+ \ingroup UTILITY
+ \copydoc ci_deflate_to_membuf(char *inbuf, size_t inlen, struct ci_membuf *outbuf, ci_off_t max_size)
+ */
+CI_DECLARE_FUNC(int) ci_gzip_to_simple_file(const char *inbuf, size_t inlen, struct ci_simple_file *outbuf, ci_off_t max_size);
+
+/**
+ * Compress bzip2 uncompressed data and writes the output to the outbuf object
+ \ingroup UTILITY
+ *
+ \param inbuf   is a buffer which holds the unzipped data
+ \param inlen is the length of the buffer buf
+ \param outbuf where to put zipped data
+ \param max_size if it is greater than zero, the output data limit
+ \return CI_COMP_OK on success, CI_COMP_ERR_NONE, if maxsize exceed, an
+ *       CI_COMPRESS_ERRORS code otherwise
+ */
+CI_DECLARE_FUNC(int) ci_bzzip_to_membuf(const char *inbuf, size_t inlen, struct ci_membuf *outbuf, ci_off_t max_size);
+
+/**
+ \ingroup UTILITY
+ \copydoc ci_bzzip_to_membuf(char *inbuf, size_t inlen, struct ci_membuf *outbuf, ci_off_t max_size)
+ */
+CI_DECLARE_FUNC(int) ci_bzzip_to_simple_file(const char *inbuf, size_t inlen, struct ci_simple_file *outbuf, ci_off_t max_size);
+
+/**
+ * Compress brotli uncompressed data and writes the output to the outbuf object
+ \ingroup UTILITY
+ *
+ \param inbuf   is a buffer which holds the unzipped data
+ \param inlen is the length of the buffer buf
+ \param outbuf where to put zipped data
+ \param max_size if it is greater than zero, the output data limit
+ \return CI_COMP_OK on success, CI_COMP_ERR_NONE, if maxsize exceed, an
+ *       CI_COMPRESS_ERRORS code otherwise
+ */
+CI_DECLARE_FUNC(int) ci_brdeflate_to_membuf(const char *inbuf, size_t inlen, struct ci_membuf *outbuf, ci_off_t max_size);
+
+/**
+ \ingroup UTILITY
+ \copydoc ci_brdeflate_to_membuf(char *inbuf, size_t inlen, struct ci_membuf *outbuf, ci_off_t max_size)
+ */
+CI_DECLARE_FUNC(int) ci_brdeflate_to_simple_file(const char *inbuf, size_t inlen, struct ci_simple_file *outbuf, ci_off_t max_size);
+
 /**
  * Decodes a base64 encoded string, and also allocate memory for the result.
  \ingroup UTILITY
@@ -278,7 +446,7 @@ CI_DECLARE_FUNC(ci_headers_list_t *) ci_http_request_headers(ci_request_t *req);
  \param header is a string contains the header in the form "Header: value"
  \return Pointer to the header or NULL if fails.
  */
-CI_DECLARE_FUNC(const char *) ci_http_response_add_header(ci_request_t *req,const char *header);
+CI_DECLARE_FUNC(const char *) ci_http_response_add_header(ci_request_t *req, const char *header);
 
 /**
  \ingroup HTTP
@@ -290,7 +458,7 @@ CI_DECLARE_FUNC(const char *) ci_http_response_add_header(ci_request_t *req,cons
  \param header is a string contains the header in the form "Header: value"
  \return Pointer to the header or NULL if fails.
  */
-CI_DECLARE_FUNC(const char *) ci_http_request_add_header(ci_request_t *req,const char *header);
+CI_DECLARE_FUNC(const char *) ci_http_request_add_header(ci_request_t *req, const char *header);
 
 /**
  \ingroup HTTP
@@ -385,7 +553,7 @@ CI_DECLARE_FUNC(int) ci_http_request_reset_headers(ci_request_t *req);
  \param has_body if it is non zero the HTTP response contains HTTP body data
  \return non zero on success zero otherwise
  */
-CI_DECLARE_FUNC(int) ci_http_response_create(ci_request_t *req, int has_reshdr ,int has_body);
+CI_DECLARE_FUNC(int) ci_http_response_create(ci_request_t *req, int has_reshdr, int has_body);
 
 /**
  \ingroup HTTP
@@ -396,7 +564,7 @@ CI_DECLARE_FUNC(int) ci_http_response_create(ci_request_t *req, int has_reshdr ,
  \param has_body if it is non zero the HTTP request contains HTTP body data
  \return non zero on success zero otherwise
  */
-CI_DECLARE_FUNC(int) ci_http_request_create(ci_request_t * req, int has_body);
+CI_DECLARE_FUNC(int) ci_http_request_create(ci_request_t *req, int has_body);
 
 /**
  \ingroup HTTP
@@ -411,6 +579,15 @@ CI_DECLARE_FUNC(int) ci_http_request_create(ci_request_t * req, int has_body);
  */
 CI_DECLARE_FUNC(ci_off_t) ci_http_content_length(ci_request_t *req);
 
+/**
+ * Return the encoding method integer representation from string.
+ \ingroup UTILITY
+ *
+ \param req is a pointer to the current ICAP request object.
+ \return the content encoding, CI_ENCODE_NONE for no encoding or CI_ENCODE_UNKNOWN for non RESPMOD ICAP requests
+*/
+CI_DECLARE_FUNC(int) ci_http_response_content_encoding(ci_request_t *req);
+
 /**
  \ingroup HTTP
  \brief Returns the request line (e.g "GET /index.html HTTP 1.0") from http
@@ -463,7 +640,7 @@ CI_DECLARE_FUNC(const char *) ci_icap_add_xheader(ci_request_t *req, const char
  \param headers is a pointer to the headers object to add
  \return pointer to the header in success or NULL otherwise
  */
-CI_DECLARE_FUNC(int) ci_icap_append_xheaders(ci_request_t *req,ci_headers_list_t *headers);
+CI_DECLARE_FUNC(int) ci_icap_append_xheaders(ci_request_t *req, ci_headers_list_t *headers);
 
 
 #ifdef __CI_COMPAT
